import * as eks from '@aws-cdk/aws-eks';
import * as cdk from '@aws-cdk/core';
export interface VpcCniAddonProps extends EksManagedAddonProps {
    readonly addonVersion?: VpcCniAddonVersion;
}
interface EksManagedAddonProps {
    readonly cluster: eks.Cluster;
    readonly addonVersion?: AddonVersion;
    readonly resolveConflicts?: boolean;
    readonly namespace?: string;
}
declare abstract class AddonVersion {
    readonly version: string;
    static of(version: string): void;
    /**
     * @param version add-on version.
     * @stability stable
     */
    protected constructor(version: string);
}
/**
 * vpc-cni add-on versions.
 *
 * @stability stable
 */
export declare class VpcCniAddonVersion extends AddonVersion {
    /**
     * vpc-cni version 1.6.3.
     *
     * @stability stable
     */
    static readonly V1_6_3: VpcCniAddonVersion;
    /**
     * vpc-cni version 1.7.5.
     *
     * @stability stable
     */
    static readonly V1_7_5: VpcCniAddonVersion;
    /**
     * vpc-cni version 1.7.6.
     *
     * @stability stable
     */
    static readonly V1_7_6: VpcCniAddonVersion;
    /**
     * vpc-cni version 1.7.9.
     *
     * @stability stable
     */
    static readonly V1_7_9: VpcCniAddonVersion;
    /**
     * Custom add-on version.
     *
     * @param version custom add-on version.
     * @stability stable
     */
    static of(version: string): VpcCniAddonVersion;
}
interface EksManagedAddonAbstractProps {
    readonly cluster: eks.Cluster;
    readonly addonName: string;
    readonly addonVersion?: AddonVersion;
    readonly resolveConflicts?: boolean;
    readonly serviceAccountName?: string;
    readonly awsManagedPolicyName?: string;
    readonly namespace?: string;
}
declare abstract class EksManagedAddonAbstract extends eks.CfnAddon {
    protected constructor(scope: cdk.Construct, id: string, props: EksManagedAddonAbstractProps);
}
export declare class VpcCniAddon extends EksManagedAddonAbstract {
    constructor(scope: cdk.Construct, id: string, props: VpcCniAddonProps);
}
export {};
